Attribute VB_Name = "basIni"
Declare Function GetPrivateProfileString Lib "kernel32" Alias "GetPrivateProfileStringA" (ByVal lpApplicationName As String, ByVal lpKeyName As Any, ByVal lpDefault As String, ByVal lpReturnedString As String, ByVal nSize As Long, ByVal lpFileName As String) As Long
Declare Function WritePrivateProfileString Lib "kernel32" Alias "WritePrivateProfileStringA" (ByVal lpApplicationName As String, ByVal lpKeyName As Any, ByVal lpString As Any, ByVal lpFileName As String) As Long
Option Explicit

Public Sub InsureKeyIsNotBlank(sKey$, sDefault$, Optional sSection$, Optional sIniFile$)
'Insures an INI file key value is non-blank. A key will be created with the
'value specified in sDefault$ if the key does not exist or is blank. For example,
'"wallpaper=" will be changed to "wallpaper=brick.bmp" (if sDefault is "brick.bmp").
'This sub is used when setting up INI files at program initialization.
Dim sValue As String
Dim lLength As Long
    If sIniFile = "" Then sIniFile = IniFileName()
    If sSection = "" Then sSection = LCase(App.EXEName)
    sValue = String$(255, 0)
    lLength = GetPrivateProfileString(sSection, sKey, "", sValue, 255, sIniFile)
    If lLength < 1 Then
        sValue = ""
    Else
        sValue = Left$(sValue, lLength)
    End If
    If sValue = "" Then
        WritePrivateProfileString sSection, sKey, sDefault, sIniFile
    End If
End Sub


Public Sub InsureKeyExists(sKey$, sValue$, Optional sSection$, Optional sIniFile$)
'Insures an INI file key exists. A key will be created with the value
'specified in sValue if the key does not already exist. A blank key will
'be left alone. For example, "wallpaper=" will be untouched. This
'is used when setting up INI files at program initialization.
    If sIniFile = "" Then sIniFile = IniFileName()
    If sSection = "" Then sSection = LCase(App.EXEName)
    If Not KeyExists(sSection, sKey, sIniFile) Then
        WritePrivateProfileString sSection, sKey, sValue, sIniFile
    End If
End Sub



Public Function KeyExists(sKeyName$, Optional sSectionName$, Optional sIniFile$) As Boolean
Dim lReturnValue As Long
Dim sKeys As String
    If sIniFile = "" Then sIniFile = IniFileName()
    If sSectionName = "" Then sSectionName = LCase(App.EXEName)
    sKeys = String$(32767, 0)
    lReturnValue = GetPrivateProfileString(sKeyName, vbNullString, "", sKeys, 32767, sIniFile)
    sKeys = vbNullChar & Left$(sKeys, lReturnValue) & vbNullChar
    If InStr(sKeys, sSectionName) = 0 Then
        KeyExists = False
    Else
        KeyExists = True
    End If
End Function

Function IniFileName() As String
Dim sIniFile As String
Dim lLength As Long
Dim sValue As String
    'Get the base private ini file name
    If Right$(App.Path, 1) = "\" Then
        sIniFile = App.Path
    Else
        sIniFile = App.Path & "\"
    End If
    sIniFile = sIniFile & LCase$(App.EXEName) & ".ini"
    'Check to see if it exists before going further
    If Dir$(sIniFile) = "" Then
        IniFileName = sIniFile
        Exit Function
    End If
    'Check for shared ini file under [Program] IniFile=
    sValue = String$(255, 0)
    lLength = GetPrivateProfileString(LCase(App.EXEName), "IniFile", "", sValue, 255, sIniFile)
    If lLength > 0 Then sIniFile = Left$(sValue, lLength)
    IniFileName = sIniFile
End Function


Public Sub InitializeIniFile()
Dim lLength As Long
Dim sIniFile As String
Dim sProgramName As String
    If Right(App.Path, 1) = "\" Then
        sProgramName = App.Path & LCase(App.EXEName) & ".exe"
    Else
        sProgramName = App.Path & "\" & LCase(App.EXEName) & ".exe"
    End If
    sIniFile = IniFileName()
    'Create the INI file if it doesn't exist by writing one entry
    WritePrivateProfileString LCase(App.EXEName), "Program", sProgramName, sIniFile
    'Create a reference to a shared INI file
    InsureKeyIsNotBlank "IniFile", sIniFile
'    'Create a log file
'    InsureKeyExists "LogFile", App.Path & "\" & LCase(App.EXEName) & ".log"
'    If Dir$(GetIni("LogFile")) = "" Then
'        Open GetIni("LogFile") For Output As #1
'        Close #1
'    End If
InsureKeyIsNotBlank "TnefTop", "1500"
InsureKeyIsNotBlank "TnefLeft", "2000"
InsureKeyIsNotBlank "FileOpenTop", "1500"
InsureKeyIsNotBlank "FileOpenLeft", "2000"
InsureKeyIsNotBlank "FileSaveAsTop", "1500"
InsureKeyIsNotBlank "FileSaveAsLeft", "2000"
InsureKeyIsNotBlank "FileOpen", "C:\"
InsureKeyIsNotBlank "FileSaveAs", "C:\"
InsureKeyIsNotBlank "CheckedAction", "0"
InsureKeyIsNotBlank "CheckedExtension", "0"
InsureKeyIsNotBlank "Extension0", "JPG"
InsureKeyIsNotBlank "Extension1", "GIF"
InsureKeyIsNotBlank "Extension2", "ZIP"
InsureKeyIsNotBlank "Extension3", "EXE"
InsureKeyIsNotBlank "Extension4", "DLL"
InsureKeyIsNotBlank "Extension5", "OCX"
InsureKeyIsNotBlank "Extension6", "WRI"
InsureKeyIsNotBlank "Extension7", "BMP"
InsureKeyIsNotBlank "Extension8", "DOC"
InsureKeyIsNotBlank "Extension9", "XLS"
InsureKeyIsNotBlank "Extension10", "PPT"
InsureKeyIsNotBlank "Extension11", "WAV"
InsureKeyIsNotBlank "Extension12", "MID"
InsureKeyIsNotBlank "Extension13", "AVI"
InsureKeyIsNotBlank "Header0", ""
InsureKeyIsNotBlank "Header1", "GIF8"
InsureKeyIsNotBlank "Header2", "PK"
InsureKeyIsNotBlank "Header3", "MZ"
InsureKeyIsNotBlank "Header4", "MZ"
InsureKeyIsNotBlank "Header5", "MZ"
InsureKeyIsNotBlank "Header6", "1" & Chr$(190)
InsureKeyIsNotBlank "Header7", "BM"
InsureKeyIsNotBlank "Header8", Chr$(208) & Chr$(207)
InsureKeyIsNotBlank "Header9", Chr$(208) & Chr$(207)
InsureKeyIsNotBlank "Header10", Chr$(208) & Chr$(207)
InsureKeyIsNotBlank "Header11", "RIFF"
InsureKeyIsNotBlank "Header12", "RIFF"
InsureKeyIsNotBlank "Header13", "RIFF"
End Sub

Public Function GetIni(sKey$, Optional sSection$, Optional sIniFile$)
Dim sValue As String
Dim lLength As Long
    If sIniFile = "" Then sIniFile = IniFileName()
    If sSection = "" Then sSection = LCase(App.EXEName)
    sValue = String$(255, 0)
    lLength = GetPrivateProfileString(sSection, sKey, "", sValue, 255, sIniFile)
    If lLength < 1 Then
        GetIni = ""
    Else
        GetIni = Left$(sValue, lLength)
    End If
End Function

Public Function SectionExists(Optional sSectionName$, Optional sIniFile$) As Boolean
Dim lReturnValue As Long
Dim sSections As String
    If sIniFile = "" Then sIniFile = IniFileName()
    If sSectionName = "" Then sSectionName = LCase(App.EXEName)
    sSections = String$(32767, 0)
    lReturnValue = GetPrivateProfileString(vbNullString, "", "", sSections, 32767, sIniFile)
    sSections = Left$(sSections, lReturnValue)
    
    If InStr(sSections, vbNullChar & sSectionName & vbNullChar) = 0 Then
        If InStr(sSections, sSectionName & vbNullChar) = 1 Then
            SectionExists = True
        Else
            SectionExists = False
        End If
    Else
        SectionExists = True
    End If
End Function

Sub SetIni(sKey$, sValue$, Optional sSection$, Optional sIniFile$)
Dim lLength As Long
    If sIniFile = "" Then sIniFile = IniFileName()
    If sSection = "" Then sSection = LCase(App.EXEName)
    'Actually write the value
    lLength = WritePrivateProfileString(sSection, sKey, sValue, sIniFile)
End Sub


